16.54. cdist-type__grafana_dashboard(7) — cdist 6.5.4 documentation

# 16.54. cdist-type__grafana_dashboard(7)

## 16.54.1. NAME

cdist-type__grafana_dashboard - Install Grafana (https://grafana.com)

## 16.54.2. DESCRIPTION

This cdist type adds the Grafana repository, installs the grafana package, and sets the server to start on boot.

This is a singleton type.

## 16.54.3. REQUIRED PARAMETERS

None.

## 16.54.4. OPTIONAL PARAMETERS

None.

## 16.54.5. EXAMPLES

    __grafana_dashboard

## 16.54.6. AUTHORS

Kamila Součková <kamila@ksp.sk>

## 16.54.7. COPYING

Copyright (C) 2017 Kamila Součková. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.